/*
 * Copyright (c) 2006-2012 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.commandparser.commands.global;

import com.dmdirc.FrameContainer;
import com.dmdirc.WritableFrameContainer;
import com.dmdirc.commandparser.BaseCommandInfo;
import com.dmdirc.commandparser.CommandArguments;
import com.dmdirc.commandparser.CommandInfo;
import com.dmdirc.commandparser.CommandManager;
import com.dmdirc.commandparser.CommandType;
import com.dmdirc.commandparser.commands.Command;
import com.dmdirc.commandparser.commands.IntelligentCommand;
import com.dmdirc.commandparser.commands.context.CommandContext;
import com.dmdirc.commandparser.parsers.GlobalCommandParser;
import com.dmdirc.plugins.PluginInfo;
import com.dmdirc.ui.input.AdditionalTabTargets;
import com.dmdirc.ui.input.TabCompleter;

/**
 * The if plugin command allows the user to execute commands based on whether
 * or not a plugin is loaded.
 */
public class Ifplugin extends Command implements IntelligentCommand {

    /** A command info object for this command. */
    public static final CommandInfo INFO = new BaseCommandInfo("ifplugin",
            "ifplugin <[!]plugin> <command> - executes a command if the "
            + "specified plugin is/isn't loaded",
            CommandType.TYPE_GLOBAL);

    /** {@inheritDoc} */
    @Override
    public void execute(final FrameContainer origin,
            final CommandArguments args, final CommandContext context) {
        if (args.getArguments().length <= 1) {
            showUsage(origin, args.isSilent(), "ifplugin", "<[!]plugin> <command>");
            return;
        }

        final boolean negative = args.getArguments()[0].charAt(0) == '!';

        final String pname = args.getArguments()[0].substring(negative ? 1 : 0);

        final PluginInfo pluginInfo = getController().getMain().getPluginManager().getPluginInfoByName(pname);

        boolean result = true;

        if (pluginInfo == null || !pluginInfo.isLoaded()) {
            result = false;
        }

        if (result != negative) {
            if (origin == null) {
                new GlobalCommandParser(origin.getConfigManager(),
                        CommandManager.getCommandManager()).parseCommand(
                        null, args.getArgumentsAsString(1));
            } else {
                ((WritableFrameContainer) origin).getCommandParser()
                        .parseCommand(origin, args.getArgumentsAsString(1));
            }
        }
    }

    /** {@inheritDoc} */
    @Override
    public AdditionalTabTargets getSuggestions(final int arg,
            final IntelligentCommandContext context) {
        final AdditionalTabTargets res;

        if (arg == 0) {
            res = new AdditionalTabTargets().excludeAll();

            for (PluginInfo possPlugin
                    : getController().getMain().getPluginManager().getPluginInfos()) {
                res.add(possPlugin.getMetaData().getName());
                res.add("!" + possPlugin.getMetaData().getName());
            }
        } else {
            res = TabCompleter.getIntelligentResults(arg, context, 1);
        }

        return res;
    }

}
